@@ -176,20 +176,22 @@ int checkpeerlocal(int sock)
 	struct sockaddr_in6 sin6;
 	struct sockaddr sa;
     } addr;
-    socklen_t size;
     int rc = -2;
 
-    /* obtain peer address */
-    size = sizeof(addr);
 #ifdef TEST_LOCAL
     (void)sock;
     memcpy(&addr, &tstaddr, sizeof(addr));
 #else
-    if (getpeername(sock, &addr.sa, &size)) {
-	if (errno == ENOTSOCK)
-	    return 1;
-	else
-	    return -1;
+    {
+	socklen_t size = sizeof(addr);
+
+	/* obtain peer address */
+	if (getpeername(sock, &addr.sa, &size)) {
+	    if (errno == ENOTSOCK)
+		return 1;
+	    else
+		return -1;
+	}
     }
 #endif
 
@@ -473,7 +475,7 @@ int main(int argc, char *argv[])
 	    printf("\n");
 	printf("=== argument %s ===\n", argv[i]);
 	memset(&hints, 0, sizeof(hints));
-	hints.ai_family = strchr(argv[i], ':') ? AF_INET6 : AF_INET;
+	hints.ai_family = AF_UNSPEC;
 	hints.ai_socktype = SOCK_STREAM;
 	x = getaddrinfo(argv[i], NULL, &hints, &res);
 	if (x) {
