@@ -617,8 +617,8 @@ readconfig(int logtostderr)
 		}
 		if (pp != qp) continue;
 		if (strcasecmp(p->name, q->name)) continue;
-		syslog(LOG_ERR, "Duplicate definition for server %s port %hu", p->name, pp);
-		fprintf(stderr, "Duplicate definition for server %s port %hu\n", p->name, pp);
+		syslog(LOG_ERR, "Duplicate definition for server %s port %u", p->name, (unsigned int)pp);
+		fprintf(stderr, "Duplicate definition for server %s port %u\n", p->name, (unsigned int)pp);
 		return 0;
 	    }
 	}
